Struct ZwpPrimarySelectionOfferV1
pub struct ZwpPrimarySelectionOfferV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
offer to transfer primary selection contents
A wp_primary_selection_offer represents an offer to transfer the contents of the primary selection clipboard to the client. Similar to wl_data_offer, the offer also describes the mime types that the data can be converted to and provides the mechanisms for transferring the data directly to the client.
See also the Request enum for this interface.
Implementations